contain lorawan with serial_rx enabled

Dependencies:   pulga-lorawan-drv SPI_MX25R Si1133 BME280

Files at this revision

API Documentation at this revision

Comitter:
mbed_official
Date:
Tue Sep 03 14:01:54 2019 +0100
Parent:
56:39847849d219
Child:
58:4d1114ac60aa
Commit message:
Merge pull request #140 from bentcooke/add_sx126x

add SX126X radio option and update driver lib
.
Commit copied from https://github.com/ARMmbed/mbed-os-example-lorawan

Changed in this revision

README.md Show annotated file Show diff for this revision Revisions of this file
config/SX126X_example_config.json Show annotated file Show diff for this revision Revisions of this file
config/SX127X_example_config.json Show annotated file Show diff for this revision Revisions of this file
lora_radio_helper.h Show annotated file Show diff for this revision Revisions of this file
mbed-lora-radio-drv.lib Show annotated file Show diff for this revision Revisions of this file
mbed_app.json Show annotated file Show diff for this revision Revisions of this file
--- a/README.md	Wed Aug 21 07:01:49 2019 +0100
+++ b/README.md	Tue Sep 03 14:01:54 2019 +0100
@@ -1,13 +1,26 @@
 # Example LoRaWAN application for Mbed-OS
 
-This is an example application based on `Mbed-OS` LoRaWAN protocol APIs. The Mbed-OS LoRaWAN stack implementation is compliant with LoRaWAN v1.0.2 specification. 
+This is an example application based on `Mbed-OS` LoRaWAN protocol APIs. The Mbed-OS LoRaWAN stack implementation is compliant with LoRaWAN v1.0.2 specification.  See this [link](https://os.mbed.com/blog/entry/Introducing-LoRaWAN-11-support/) for information on support for other LoRaWAN spec versions. This application can work with any Network Server if you have correct credentials for the said Network Server. 
+
+## Getting Started
 
-## Getting started
+### Supported Hardware
+[Mbed Enabled board with an Arduino form factor](https://os.mbed.com/platforms/?q=&Form+Factor=Arduino+Compatible) and one of the following:
+- [SX126X shield](https://os.mbed.com/components/SX126xMB2xAS/)
+- [SX1276 shield](https://os.mbed.com/components/SX1276MB1xAS/)
+- [SX1272 shield](https://os.mbed.com/components/SX1272MB2xAS/) 
 
-This application can work with any Network Server if you have correct credentials for the said Network Server. 
+OR
+
+[Mbed Enabled LoRa Module](#module-support)
 
-### Download the application
+### Import the example application
+For [Mbed Online Compiler](https://ide.mbed.com/compiler/) users:
+- Select "Import", then search for "mbed-os-example-lorawan" from "Team mbed-os-examples".  Or simply, import this repo by URL.
 
+- NOTE: Do NOT select "Update all libraries to latest revision" as this may cause breakage with a new lib version we have not tested.   
+
+For [mbed-cli](https://github.com/ARMmbed/mbed-cli) users:
 ```sh
 $ mbed import mbed-os-example-lorawan
 $ cd mbed-os-example-lorawan
@@ -19,20 +32,15 @@
 $ mbed deploy
 ```
 
-### Selecting radio
+### Example configuration and radio selection
 
-Mbed OS provides inherent support for a variety of modules. If your device is one of the those modules, you may skip this part. The correct radio type and pin set is already provided for the modules in the `target-overrides` field. For more information on supported modules, please refer to the [module support section](#module-support)
-
-If you are using an Mbed Enabled radio shield such as [Mbed SX1276 shield LoRa](https://os.mbed.com/components/SX1276MB1xAS/) or [Mbed SX1272 LoRa shield ](https://os.mbed.com/components/SX1272MB2xAS/) with any Mbed Enabled board, this part is relevant. You can use any Mbed Enabled board that comes with an arduino form factor.
+Because of the pin differences between the SX126x and SX127x radios, example application configuration files are provided with the correct pin sets in the `config/` dir of this project. 
 
-Please select your radio type by modifying the `lora-radio` field in `mbed_app.json` and providing a pin set if it is different from the default. For example:
+Please start by selecting the correct example configuration for your radio:  
+- For [Mbed Online Compiler](https://ide.mbed.com/compiler/) users, this can be done by simply replacing the contents of the `mbed_app.json` at the root of the project with the content of the correct example configuration in `config/` dir.
+- For [mbed-cli](https://github.com/ARMmbed/mbed-cli) users, the config file can be specifed on the command line with the `--app-config` option (ie `--app-config config/SX12xx_example_config.json`)
 
-```json
-"lora-radio": {
-    "help": "Which radio to use (options: SX1272,SX1276)",
-    "value": "SX1272"
-},
-```
+With the correct config file selected, the user can then provide a pin set for their target board in the `NC` fields at the top if it is different from the default targets listed.  If your device is one of the LoRa modules supported by Mbed-OS, the pin set is already provided for the modules in the `target-overrides` field of the config file. For more information on supported modules, please refer to the [module support section](#module-support)
 
 ### Add network credentials
 
@@ -43,7 +51,6 @@
 Please add `Device EUI`, `Application EUI` and `Application Key` needed for Over-the-air-activation(OTAA). For example:
 
 ```json
-
 "lora.device-eui": "{ YOUR_DEVICE_EUI }",
 "lora.application-eui": "{ YOUR_APPLICATION_EUI }",
 "lora.application-key": "{ YOUR_APPLICATION_KEY }"
@@ -99,15 +106,15 @@
 
 Here is a nonexhaustive list of boards and modules that we have tested with the Mbed OS LoRaWAN stack:
 
-- MultiTech mDot.
-- MultiTech xDot.
-- LTEK_FF1705.
-- Advantech Wise 1510.
-- ST B-L072Z-LRWAN1 LoRa®Discovery kit (with muRata radio chip).
+- MultiTech mDot (SX1272)
+- MultiTech xDot (SX1272)
+- LTEK_FF1705 (SX1272)
+- Advantech Wise 1510 (SX1276)
+- ST B-L072Z-LRWAN1 LoRa®Discovery kit with Murata CMWX1ZZABZ-091 module (SX1276)
 
 Here is a list of boards and modules that have been tested by the community:
 
-- IMST iM880B.
+- IMST iM880B (SX1272)
 
 ## Compiling the application
 
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/config/SX126X_example_config.json	Tue Sep 03 14:01:54 2019 +0100
@@ -0,0 +1,65 @@
+{
+    "config": {
+        "lora-radio": {
+            "help": "Which radio to use (options: SX126X, SX1272, SX1276) -- See config/ dir for example configs",
+            "value": "SX126X"
+        },
+        "main_stack_size":     { "value": 4096 },
+
+        "lora-spi-mosi":       { "value": "NC" },
+        "lora-spi-miso":       { "value": "NC" },
+        "lora-spi-sclk":       { "value": "NC" },
+        "lora-cs":             { "value": "NC" },
+        "lora-reset":          { "value": "NC" },
+        "lora-dio1":           { "value": "NC" },
+        "lora-busy":           { "value": "NC" },
+        "lora-freq-sel":       { "value": "NC" },
+        "lora-dev-sel":        { "value": "NC" },
+        "lora-xtal-sel":       { "value": "NC" }, 
+        "lora-ant-switch":     { "value": "NC" }
+    
+    },
+    "target_overrides": {
+        "*": {
+            "platform.stdio-convert-newlines": true,
+            "platform.stdio-baud-rate": 115200,
+            "platform.default-serial-baud-rate": 115200,
+            "lora.over-the-air-activation": true,
+            "lora.duty-cycle-on": true,
+            "lora.phy": "EU868",
+            "lora.device-eui": "{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }",
+            "lora.application-eui": "{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }",
+            "lora.application-key": "{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }"
+        },
+
+        "NUCLEO_L073RZ": {
+            "main_stack_size":     2048,
+            "lora-spi-mosi":       "D11",
+            "lora-spi-miso":       "D12",
+            "lora-spi-sclk":       "D13",
+            "lora-cs":             "D7",
+            "lora-reset":          "A0",
+            "lora-dio1":           "D5",
+            "lora-busy":           "D3",
+            "lora-freq-sel":       "A1",
+            "lora-dev-sel":        "A2",
+            "lora-xtal-sel":       "A3",
+            "lora-ant-switch":     "D8"
+        },
+
+        "K64F": {
+            "lora-spi-mosi":       "D11",
+            "lora-spi-miso":       "D12",
+            "lora-spi-sclk":       "D13",
+            "lora-cs":             "D7",
+            "lora-reset":          "A0",
+            "lora-dio1":           "D5",
+            "lora-busy":           "D3",
+            "lora-freq-sel":       "A1",
+            "lora-dev-sel":        "A2",
+            "lora-xtal-sel":       "A3",
+            "lora-ant-switch":     "D8"
+        }
+    },
+    "macros": ["MBEDTLS_USER_CONFIG_FILE=\"mbedtls_lora_config.h\""]
+}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/config/SX127X_example_config.json	Tue Sep 03 14:01:54 2019 +0100
@@ -0,0 +1,264 @@
+{
+    "config": {
+        "lora-radio": {
+            "help": "Which radio to use (options: SX126X, SX1272, SX1276) -- See config/ dir for example configs",
+            "value": "SX1276"
+    },
+    "main_stack_size":     { "value": 4096 },
+
+        "lora-spi-mosi":       { "value": "NC" },
+        "lora-spi-miso":       { "value": "NC" },
+        "lora-spi-sclk":       { "value": "NC" },
+        "lora-cs":             { "value": "NC" },
+        "lora-reset":          { "value": "NC" },
+        "lora-dio0":           { "value": "NC" },
+        "lora-dio1":           { "value": "NC" },
+        "lora-dio2":           { "value": "NC" },
+        "lora-dio3":           { "value": "NC" },
+        "lora-dio4":           { "value": "NC" },
+        "lora-dio5":           { "value": "NC" },
+        "lora-rf-switch-ctl1": { "value": "NC" },
+        "lora-rf-switch-ctl2": { "value": "NC" },
+        "lora-txctl":          { "value": "NC" },
+        "lora-rxctl":          { "value": "NC" },
+        "lora-ant-switch":     { "value": "NC" },
+        "lora-pwr-amp-ctl":    { "value": "NC" },
+        "lora-tcxo":           { "value": "NC" }
+    },
+    "target_overrides": {
+        "*": {
+            "platform.stdio-convert-newlines": true,
+            "platform.stdio-baud-rate": 115200,
+            "platform.default-serial-baud-rate": 115200,
+            "lora.over-the-air-activation": true,
+            "lora.duty-cycle-on": true,
+            "lora.phy": "EU868",
+            "lora.device-eui": "{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }",
+            "lora.application-eui": "{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }",
+            "lora.application-key": "{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }"
+        },
+
+        "K64F": {
+            "lora-spi-mosi":       "D11",
+            "lora-spi-miso":       "D12",
+            "lora-spi-sclk":       "D13",
+            "lora-cs":             "D10",
+            "lora-reset":          "A0",
+            "lora-dio0":           "D2",
+            "lora-dio1":           "D3",
+            "lora-dio2":           "D4",
+            "lora-dio3":           "D5",
+            "lora-dio4":           "D8",
+            "lora-dio5":           "D9",
+            "lora-rf-switch-ctl1": "NC",
+            "lora-rf-switch-ctl2": "NC",
+            "lora-txctl":          "NC",
+            "lora-rxctl":          "NC",
+            "lora-ant-switch":     "A4",
+            "lora-pwr-amp-ctl":    "NC",
+            "lora-tcxo":           "NC"
+        },
+
+        "DISCO_L072CZ_LRWAN1": {
+            "main_stack_size":      1024,
+            "lora-radio":          "SX1276",
+            "lora-spi-mosi":       "PA_7",
+            "lora-spi-miso":       "PA_6",
+            "lora-spi-sclk":       "PB_3",
+            "lora-cs":             "PA_15",
+            "lora-reset":          "PC_0",
+            "lora-dio0":           "PB_4",
+            "lora-dio1":           "PB_1",
+            "lora-dio2":           "PB_0",
+            "lora-dio3":           "PC_13",
+            "lora-dio4":           "NC",
+            "lora-dio5":           "NC",
+            "lora-rf-switch-ctl1": "NC",
+            "lora-rf-switch-ctl2": "NC",
+            "lora-txctl":          "PC_2",
+            "lora-rxctl":          "PA_1",
+            "lora-ant-switch":     "NC",
+            "lora-pwr-amp-ctl":    "PC_1",
+            "lora-tcxo":           "PA_12"
+        },
+
+        "MTB_MURATA_ABZ": {
+            "main_stack_size":      1024,
+            "lora-radio":          "SX1276",
+            "lora-spi-mosi":       "PA_7",
+            "lora-spi-miso":       "PA_6",
+            "lora-spi-sclk":       "PB_3",
+            "lora-cs":             "PA_15",
+            "lora-reset":          "PC_0",
+            "lora-dio0":           "PB_4",
+            "lora-dio1":           "PB_1",
+            "lora-dio2":           "PB_0",
+            "lora-dio3":           "PC_13",
+            "lora-dio4":           "NC",
+            "lora-dio5":           "NC",
+            "lora-rf-switch-ctl1": "NC",
+            "lora-rf-switch-ctl2": "NC",
+            "lora-txctl":          "PC_2",
+            "lora-rxctl":          "PA_1",
+            "lora-ant-switch":     "NC",
+            "lora-pwr-amp-ctl":    "PC_1",
+            "lora-tcxo":           "PA_12"
+        },
+
+        "XDOT_L151CC": {
+            "lora-radio":           "SX1272",
+            "lora-spi-mosi":        "LORA_MOSI",
+            "lora-spi-miso":        "LORA_MISO",
+            "lora-spi-sclk":        "LORA_SCK",
+            "lora-cs":              "LORA_NSS",
+            "lora-reset":           "LORA_RESET",
+            "lora-dio0":            "LORA_DIO0",
+            "lora-dio1":            "LORA_DIO1",
+            "lora-dio2":            "LORA_DIO2",
+            "lora-dio3":            "LORA_DIO3",
+            "lora-dio4":            "LORA_DIO4",
+            "lora-dio5":            "NC",
+            "lora-rf-switch-ctl1":  "NC",
+            "lora-rf-switch-ctl2":  "NC",
+            "lora-txctl":           "NC",
+            "lora-rxctl":           "NC",
+            "lora-ant-switch":      "NC",
+            "lora-pwr-amp-ctl":     "NC",
+            "lora-tcxo":            "NC"
+        },
+
+        "MTB_MTS_XDOT": {
+            "lora-radio":           "SX1272",
+            "lora-spi-mosi":        "LORA_MOSI",
+            "lora-spi-miso":        "LORA_MISO",
+            "lora-spi-sclk":        "LORA_SCK",
+            "lora-cs":              "LORA_NSS",
+            "lora-reset":           "LORA_RESET",
+            "lora-dio0":            "LORA_DIO0",
+            "lora-dio1":            "LORA_DIO1",
+            "lora-dio2":            "LORA_DIO2",
+            "lora-dio3":            "LORA_DIO3",
+            "lora-dio4":            "LORA_DIO4",
+            "lora-dio5":            "NC",
+            "lora-rf-switch-ctl1":  "NC",
+            "lora-rf-switch-ctl2":  "NC",
+            "lora-txctl":           "NC",
+            "lora-rxctl":           "NC",
+            "lora-ant-switch":      "NC",
+            "lora-pwr-amp-ctl":     "NC",
+            "lora-tcxo":            "NC"
+        },
+
+        "FF1705_L151CC": {
+            "lora-radio":           "SX1272",
+            "lora-spi-mosi":        "LORA_MOSI",
+            "lora-spi-miso":        "LORA_MISO",
+            "lora-spi-sclk":        "LORA_SCK",
+            "lora-cs":              "LORA_NSS",
+            "lora-reset":           "LORA_RESET",
+            "lora-dio0":            "LORA_DIO0",
+            "lora-dio1":            "LORA_DIO1",
+            "lora-dio2":            "LORA_DIO2",
+            "lora-dio3":            "LORA_DIO3",
+            "lora-dio4":            "LORA_DIO4",
+            "lora-dio5":            "NC",
+            "lora-rf-switch-ctl1":  "NC",
+            "lora-rf-switch-ctl2":  "NC",
+            "lora-txctl":           "NC",
+            "lora-rxctl":           "NC",
+            "lora-ant-switch":      "NC",
+            "lora-pwr-amp-ctl":     "NC",
+            "lora-tcxo":            "NC"
+        },
+
+        "MTS_MDOT_F411RE": {
+            "lora-radio":           "SX1272",
+            "lora-spi-mosi":        "LORA_MOSI",
+            "lora-spi-miso":        "LORA_MISO",
+            "lora-spi-sclk":        "LORA_SCK",
+            "lora-cs":              "LORA_NSS",
+            "lora-reset":           "LORA_RESET",
+            "lora-dio0":            "LORA_DIO0",
+            "lora-dio1":            "LORA_DIO1",
+            "lora-dio2":            "LORA_DIO2",
+            "lora-dio3":            "LORA_DIO3",
+            "lora-dio4":            "LORA_DIO4",
+            "lora-dio5":            "LORA_DIO5",
+            "lora-rf-switch-ctl1":  "NC",
+            "lora-rf-switch-ctl2":  "NC",
+            "lora-txctl":           "LORA_TXCTL",
+            "lora-rxctl":           "LORA_RXCTL",
+            "lora-ant-switch":      "NC",
+            "lora-pwr-amp-ctl":     "NC",
+            "lora-tcxo":            "NC"
+        },
+
+        "MTB_ADV_WISE_1510": {
+            "lora-radio":           "SX1276",
+            "lora-spi-mosi":        "SPI_RF_MOSI",
+            "lora-spi-miso":        "SPI_RF_MISO",
+            "lora-spi-sclk":        "SPI_RF_SCK",
+            "lora-cs":              "SPI_RF_CS",
+            "lora-reset":           "SPI_RF_RESET",
+            "lora-dio0":            "DIO0",
+            "lora-dio1":            "DIO1",
+            "lora-dio2":            "DIO2",
+            "lora-dio3":            "DIO3",
+            "lora-dio4":            "DIO4",
+            "lora-dio5":            "DIO5",
+            "lora-rf-switch-ctl1":  "NC",
+            "lora-rf-switch-ctl2":  "NC",
+            "lora-txctl":           "NC",
+            "lora-rxctl":           "NC",
+            "lora-ant-switch":      "ANT_SWITCH",
+            "lora-pwr-amp-ctl":     "NC",
+            "lora-tcxo":            "NC"
+        },
+
+        "MTB_RAK811": {
+            "lora-radio":          "SX1276",
+            "lora-spi-mosi":       "SPI_RF_MOSI",
+            "lora-spi-miso":       "SPI_RF_MISO",
+            "lora-spi-sclk":       "SPI_RF_SCK",
+            "lora-cs":             "SPI_RF_CS",
+            "lora-reset":          "SPI_RF_RESET",
+            "lora-dio0":           "DIO0",
+            "lora-dio1":           "DIO1",
+            "lora-dio2":           "DIO2",
+            "lora-dio3":           "DIO3",
+            "lora-dio4":           "DIO4",
+            "lora-dio5":           "NC",
+            "lora-rf-switch-ctl1": "NC",
+            "lora-rf-switch-ctl2": "NC",
+            "lora-txctl":          "ANT_CTX_PA",
+            "lora-rxctl":          "ANT_CRX_RX",
+            "lora-ant-switch":     "NC",
+            "lora-pwr-amp-ctl":    "NC",
+            "lora-tcxo":           "RF_TCXO_EN"
+        },
+
+        "IM880B": {
+            "main_stack_size":      1024,
+            "lora-radio":          "SX1272",
+            "lora-spi-mosi":       "SPI_RF_MOSI",
+            "lora-spi-miso":       "SPI_RF_MISO",
+            "lora-spi-sclk":       "SPI_RF_SCK",
+            "lora-cs":             "SPI_RF_NSS",
+            "lora-reset":          "SPI_RF_RESET",
+            "lora-dio0":           "DIO0",
+            "lora-dio1":           "DIO1",
+            "lora-dio2":           "DIO2",
+            "lora-dio3":           "DIO3",
+            "lora-dio4":           "DIO4",
+            "lora-dio5":           "NC",
+            "lora-rf-switch-ctl1": "NC",
+            "lora-rf-switch-ctl2": "NC",
+            "lora-txctl":          "ANT_CTX_PA",
+            "lora-rxctl":          "ANT_CRX_RX",
+            "lora-ant-switch":     "NC",
+            "lora-pwr-amp-ctl":    "NC",
+            "lora-tcxo":           "NC"
+        }
+    },
+    "macros": ["MBEDTLS_USER_CONFIG_FILE=\"mbedtls_lora_config.h\""]
+}
\ No newline at end of file
--- a/mbed-lora-radio-drv.lib	Wed Aug 21 07:01:49 2019 +0100
+++ b/mbed-lora-radio-drv.lib	Tue Sep 03 14:01:54 2019 +0100
@@ -1,1 +1,1 @@
-https://github.com/ARMmbed/mbed-semtech-lora-rf-drivers#16958f814d505cfbbedfa16d9bf8b9dff0e0442b
+https://github.com/ARMmbed/mbed-semtech-lora-rf-drivers#6012fa43cf9f2cae46fa9d424fe4051d00e157a2
--- a/mbed_app.json	Wed Aug 21 07:01:49 2019 +0100
+++ b/mbed_app.json	Tue Sep 03 14:01:54 2019 +0100
@@ -1,7 +1,7 @@
 {
     "config": {
         "lora-radio": {
-            "help": "Which radio to use (options: SX1272,SX1276)",
+            "help": "Which radio to use (options: SX126X, SX1272, SX1276) -- See config/ dir for example configs",
             "value": "SX1276"
         },
         "main_stack_size":     { "value": 4096 },
@@ -262,3 +262,4 @@
     },
     "macros": ["MBEDTLS_USER_CONFIG_FILE=\"mbedtls_lora_config.h\""]
 }
+
--- a/lora_radio_helper.h	Wed Aug 21 07:01:49 2019 +0100
+++ b/lora_radio_helper.h	Tue Sep 03 14:01:54 2019 +0100
@@ -20,14 +20,12 @@
 
 #include "lorawan/LoRaRadio.h"
 
-#include "SX1272_LoRaRadio.h"
-#include "SX1276_LoRaRadio.h"
-
 #define SX1272   0xFF
 #define SX1276   0xEE
+#define SX126X   0xDD
 
 #if (MBED_CONF_APP_LORA_RADIO == SX1272)
-
+#include "SX1272_LoRaRadio.h"
 SX1272_LoRaRadio radio(MBED_CONF_APP_LORA_SPI_MOSI,
                        MBED_CONF_APP_LORA_SPI_MISO,
                        MBED_CONF_APP_LORA_SPI_SCLK,
@@ -48,7 +46,7 @@
                        MBED_CONF_APP_LORA_TCXO);
 
 #elif (MBED_CONF_APP_LORA_RADIO == SX1276)
-
+#include "SX1276_LoRaRadio.h"
 SX1276_LoRaRadio radio(MBED_CONF_APP_LORA_SPI_MOSI,
                        MBED_CONF_APP_LORA_SPI_MISO,
                        MBED_CONF_APP_LORA_SPI_SCLK,
@@ -68,8 +66,22 @@
                        MBED_CONF_APP_LORA_PWR_AMP_CTL,
                        MBED_CONF_APP_LORA_TCXO);
 
+#elif (MBED_CONF_APP_LORA_RADIO == SX126X)
+#include "SX126X_LoRaRadio.h"
+SX126X_LoRaRadio radio(MBED_CONF_APP_LORA_SPI_MOSI,
+                       MBED_CONF_APP_LORA_SPI_MISO,
+                       MBED_CONF_APP_LORA_SPI_SCLK,
+                       MBED_CONF_APP_LORA_CS,
+                       MBED_CONF_APP_LORA_RESET,
+                       MBED_CONF_APP_LORA_DIO1,
+                       MBED_CONF_APP_LORA_BUSY,
+                       MBED_CONF_APP_LORA_FREQ_SEL,
+                       MBED_CONF_APP_LORA_DEV_SEL,
+                       MBED_CONF_APP_LORA_XTAL_SEL,
+                       MBED_CONF_APP_LORA_ANT_SWITCH);
+
 #else
 #error "Unknown LoRa radio specified (SX1272,SX1276 are valid)"
 #endif
 
 #endif /* APP_LORA_RADIO_HELPER_H_ */
@@ -68,8 +66,22 @@
 #else
-#error "Unknown LoRa radio specified (SX1272,SX1276 are valid)"
+#error "Unknown LoRa radio specified (SX126X, SX1272, SX1276 are valid)"
 #endif
 